==> mitosheet3-0.1.152.tar.gz: mitosheet3-0.1.152/mitosheet3/__init__.py <==
#!/usr/bin/env python
# coding: utf-8

# Copyright (c) Mito.
# Distributed under the terms of the Modified BSD License.

"""
The Mito package, which contains functions for creating a Mito sheet. 

To generate a new sheet, simply run:

import mitosheet
mitosheet.sheet()

If running mitosheet.sheet() just prints text that looks like `MitoWidget(...`, then you need to 
install the JupyterLab extension manager by running:

jupyter labextension install @jupyter-widgets/jupyterlab-manager@2;

Run this command in the terminal where you installed Mito. It should take 5-10 minutes to complete.

Then, restart your JupyterLab instance, and refresh your browser. Mito should now render.

NOTE: if you have any issues with installation, please email book a demo time at https://hubs.ly/H0FL1920
"""

import os
import pandas as pd
import json
from pathlib import Path

from ._version import __version__

from mitosheet.example import MitoWidget, sheet
from mitosheet.errors import CreationError, EditError
from mitosheet._version import __version__

# Export all the sheet functions
from mitosheet.sheet_functions import *
# And the functions for changing types
from mitosheet.sheet_functions.types import *

from .nbextension import _jupyter_nbextension_paths


if __name__ == 'mitosheet':
    from mitosheet.user.user import initialize_user, is_local_deployment
    # Make sure the user is created and up to date, whenever mitosheet is imported
    initialize_user()

    from mitosheet.utils import is_imported_correctly

    # We check local deployment first, as this hopefully short curcits and saves us time
    if is_local_deployment() and not is_imported_correctly():
        print("It looks like Mito is incorrectly installed. To finish installing Mito, follow the documentation here: https://docs.trymito.io/")

HERE = Path(__file__).parent.resolve()

with (HERE / "labextension" / "package.json").open() as fid:
    data = json.load(fid)

def _jupyter_labextension_paths():
    return [{
        "src": "labextension",
        "dest": data["name"]
    }]

==> mitosheet3-0.3.3.tar.gz: mitosheet3-0.3.3/mitosheet3/__init__.py <==
#!/usr/bin/env python
# coding: utf-8

# Copyright (c) Mito.
# Distributed under the terms of the Modified BSD License.

"""
The Mito package, which contains functions for creating a Mito sheet. 

To generate a new sheet, simply run:

import mitosheet
mitosheet.sheet()

If running mitosheet.sheet() just prints text that looks like `MitoWidget(...`, then you need to 
install the JupyterLab extension manager by running:

jupyter labextension install @jupyter-widgets/jupyterlab-manager@2;

Run this command in the terminal where you installed Mito. It should take 5-10 minutes to complete.

Then, restart your JupyterLab instance, and refresh your browser. Mito should now render.

NOTE: if you have any issues with installation, please email book a demo time at https://hubs.ly/H0FL1920
"""

import os
import pandas as pd
import json
from pathlib import Path

from ._version import __version__

from mitosheet3.example import MitoWidget, sheet
from mitosheet3.errors import CreationError, EditError
from mitosheet3._version import __version__

# Export all the sheet functions
from mitosheet3.sheet_functions import *
# And the functions for changing types
from mitosheet3.sheet_functions.types import *

from .nbextension import _jupyter_nbextension_paths


if __name__ == 'mitosheet':
    from mitosheet3.user.user import initialize_user
    # Make sure the user is created and up to date, whenever mitosheet is imported
    initialize_user()

HERE = Path(__file__).parent.resolve()

with (HERE / "labextension" / "package.json").open() as fid:
    data = json.load(fid)

def _jupyter_labextension_paths():
    return [{
        "src": "labextension",
        "dest": data["name"]
    }]
